'use strict';

var backendPluginApi = require('@backstage/backend-plugin-api');
var alpha = require('@backstage/plugin-search-backend-node/alpha');
var StackOverflowQuestionsCollatorFactory = require('../collators/StackOverflowQuestionsCollatorFactory.cjs.js');

const searchStackOverflowCollatorModule = backendPluginApi.createBackendModule({
  pluginId: "search",
  moduleId: "stack-overflow-collator",
  register(env) {
    env.registerInit({
      deps: {
        config: backendPluginApi.coreServices.rootConfig,
        logger: backendPluginApi.coreServices.logger,
        discovery: backendPluginApi.coreServices.discovery,
        scheduler: backendPluginApi.coreServices.scheduler,
        indexRegistry: alpha.searchIndexRegistryExtensionPoint
      },
      async init({ config, logger, scheduler, indexRegistry }) {
        const defaultSchedule = {
          frequency: { minutes: 10 },
          timeout: { minutes: 15 },
          initialDelay: { seconds: 3 }
        };
        const schedule = config.has("stackoverflow.schedule") ? backendPluginApi.readSchedulerServiceTaskScheduleDefinitionFromConfig(
          config.getConfig("stackoverflow.schedule")
        ) : defaultSchedule;
        indexRegistry.addCollator({
          schedule: scheduler.createScheduledTaskRunner(schedule),
          factory: StackOverflowQuestionsCollatorFactory.StackOverflowQuestionsCollatorFactory.fromConfig(config, {
            logger
          })
        });
      }
    });
  }
});

exports.searchStackOverflowCollatorModule = searchStackOverflowCollatorModule;
//# sourceMappingURL=SearchStackOverflowCollatorModule.cjs.js.map
